@@ -1,25 +1,20 @@
 """
 clearbit_service.py: Utility functions used by the clearbit service.
 """
-from __future__ import print_function, division, unicode_literals, \
-    absolute_import
-import sys
+__author__ = "Jason Wolosonovich <jason@avaland.io>"
+__license__ = "BSD 3 clause"
 import os
 import base64
 import time
-import requests
 
+import requests
 import googleapiclient.discovery
-from google.cloud import storage
 import clearbit
 import gcsfs
 
 from .classes import MemoryCache, MetadataMixin
 from .constants import MAX_RETRIES, SLEEP_LENGTH
 
-__author__ = "Jason Wolosonovich <jason@avaland.io>"
-__license__ = "BSD 3 clause"
-
 
 def decrypt_with_kms(project_id=None, location_id=None,
                      key_ring_id=None, crypto_key_id=None,
@@ -27,7 +22,7 @@ def decrypt_with_kms(project_id=None, location_id=None,
     """Decrypts data from ciphertext_string stored in GCS."""
     print("decrypt_with_kms()")
     # Creates an API client for the KMS API.
-    kms_client = googleapiclient \
+    kms_client = googleapiclient\
         .discovery \
         .build(
         "cloudkms",
@@ -89,14 +84,15 @@ def get_service_configs(service=None, project_name=None):
             CIPHERTEXT_BLOB = os.environ["GCP_CIPHERTEXT_BLOB"]
             BUCKET_NAME = os.environ["GCS_BUCKET"]
 
+            # DEPRECATED
             # set clearbit api versions
-            clearbit.Person.set_version("2018-06-06")
-            clearbit.Company.set_version("2017-09-12")
-            clearbit.Reveal.set_version("2018-03-28")
-            # not in use
-            clearbit.Watchlist.set_version("2015-11-13")
-            # not in use
-            clearbit.Prospector.set_version("2016-10-04")
+            # clearbit.Person.set_version("2018-06-06")
+            # clearbit.Company.set_version("2017-09-12")
+            # clearbit.Reveal.set_version("2018-03-28")
+            # # not in use
+            # clearbit.Watchlist.set_version("2015-11-13")
+            # # not in use
+            # clearbit.Prospector.set_version("2016-10-04")
 
             fs = gcsfs.GCSFileSystem(
                 project=project_name,
@@ -346,12 +342,42 @@ def make_clearbit_person_gcs_payload(request=None):
                 p["gravatar_urls"].append(d["value"])
             except KeyError as e:
                 p["gravatar_urls"].append(None)
-    p["gravatar_url_titles"] = " >>> ".join(
-        p["gravatar_url_titles"]
-    )
-    p["gravatar_urls"] = " >>> ".join(
-        p["gravatar_urls"]
-    )
+
+    if len(p["gravatar_url_titles"]) != 0:
+        if None in p["gravatar_url_titles"]:
+            p["gravatar_url_titles"] = \
+                list(set(p["gravatar_url_titles"]))
+            p["gravatar_url_titles"].remove(None)
+            if len(p["gravatar_url_titles"]) != 0:
+                p["gravatar_url_titles"] = " >>> ".join(
+                    p["gravatar_url_titles"]
+                )
+            else:
+                p["gravatar_url_titles"] = None
+        else:
+            p["gravatar_url_titles"] = " >>> ".join(
+                p["gravatar_url_titles"]
+            )
+    else:
+        p["gravatar_url_titles"] = None
+
+    if len(p["gravatar_urls"]) != 0:
+        if None in p["gravatar_urls"]:
+            p["gravatar_urls"] = list(set(p["gravatar_urls"]))
+            p["gravatar_urls"].remove(None)
+            if len(p["gravatar_urls"]) != 0:
+                p["gravatar_urls"] = " >>> ".join(
+                    p["gravatar_urls"]
+                )
+            else:
+                p["gravatar_urls"] = None
+        else:
+            p["gravatar_urls"] = " >>> ".join(
+                p["gravatar_urls"]
+            )
+    else:
+        p["gravatar_urls"] = None
+
     p["gravatar_avatar"] = r["gravatar"]["avatar"]
     p["gravatar_avatar_types"] = list()
     p["gravatar_avatar_urls"] = list()
@@ -365,18 +391,42 @@ def make_clearbit_person_gcs_payload(request=None):
                 p["gravatar_avatar_urls"].append(d["url"])
             except KeyError as e:
                 p["gravatar_avatar_urls"].append(None)
-    if p["gravatar_avatar_types"] is None:
-        pass
+
+    if len(p["gravatar_avatar_types"]) != 0:
+        if None in p["gravatar_avatar_types"]:
+            p["gravatar_avatar_types"] = \
+                list(set(p["gravatar_avatar_types"]))
+            p["gravatar_avatar_types"].remove(None)
+            if len(p["gravatar_avatar_types"]) != 0:
+                p["gravatar_avatar_types"] = " >>> ".join(
+                    p["gravatar_avatar_types"]
+                )
+            else:
+                p["gravatar_avatar_types"] = None
+        else:
+            p["gravatar_avatar_types"] = " >>> ".join(
+                p["gravatar_avatar_types"]
+            )
     else:
-        p["gravatar_avatar_types"] = " >>> ".join(
-            p["gravatar_avatar_types"]
-        )
-    if p["gravatar_avatar_urls"] is None:
-        pass
+        p["gravatar_avatar_types"] = None
+
+    if len(p["gravatar_avatar_urls"]) != 0:
+        if None in p["gravatar_avatar_urls"]:
+            p["gravatar_avatar_urls"] = \
+                list(set(p["gravatar_avatar_urls"]))
+            p["gravatar_avatar_urls"].remove(None)
+            if len(p["gravatar_avatar_urls"]) != 0:
+                p["gravatar_avatar_urls"] = " >>> ".join(
+                    p["gravatar_avatar_urls"]
+                )
+            else:
+                p["gravatar_avatar_urls"] = None
+        else:
+            p["gravatar_avatar_urls"] = " >>> ".join(
+                p["gravatar_avatar_urls"]
+            )
     else:
-        p["gravatar_avatar_urls"] = " >>> ".join(
-            p["gravatar_avatar_urls"]
-        )
+        p["gravatar_avatar_urls"] = None
 
     p["fuzzy_match"] = r["fuzzy"]
     p["is_email_provider"] = r["emailProvider"]
@@ -508,7 +558,7 @@ def clearbit_routines(request=None, streaming=False):
                         params={"ip": request["ip_address"]},
                         auth=(clearbit.key, ""),
                         headers={
-                            "API-Version": clearbit.Reveal.version
+                            "API-Version": "2018-03-28"
                         }
                     )
                 else:
@@ -517,7 +567,7 @@ def clearbit_routines(request=None, streaming=False):
                             "/find",
                         params={"ip": request["ip_address"]},
                         auth=(clearbit.key, ""),
-                        headers={"API-Version": clearbit.Reveal.version}
+                        headers={"API-Version": "2018-03-28"}
                     )
                 # DEPRECATED
                 # resp = clearbit.Reveal.find(ip=ip_address,
@@ -593,9 +643,10 @@ def clearbit_routines(request=None, streaming=False):
                             params={**params},
                             auth=(clearbit.key, ""),
                             headers={
-                                "API-Version": clearbit.Person.version
+                                "API-Version": "2018-06-06"
                             }
                         )
+
                     elif enrichment_api == "company":
                         resp = requests.get(
                             url="https://company-stream.clearbit.com/v2"
@@ -603,28 +654,26 @@ def clearbit_routines(request=None, streaming=False):
                             params={**params},
                             auth=(clearbit.key, ""),
                             headers={
-                                "API-Version": clearbit.Company.version
+                                "API-Version": "2017-09-12"
                             }
                         )
                 else:
                     if enrichment_api == "person":
                         resp = requests.get(
-                            url=
-                            "https://person.clearbit.com/v2/combined/find",
+                            url="https://person.clearbit.com/v2/combined/find",
                             params={**params},
                             auth=(clearbit.key, ""),
                             headers={
-                                "API-Version": clearbit.Person.version
+                                "API-Version": "2018-06-06"
                             }
                         )
                     elif enrichment_api == "company":
                         resp = requests.get(
-                            url=
-                            "https://company.clearbit.com/v2/companies/find",
+                            url="https://company.clearbit.com/v2/companies/find",
                             params={**params},
                             auth=(clearbit.key, ""),
                             headers={
-                                "API-Version": clearbit.Company.version
+                                "API-Version": "2017-09-12"
                             }
                         )
 
@@ -648,8 +697,9 @@ def clearbit_routines(request=None, streaming=False):
 
                 print("request sent")
                 print("status: {}".format(resp))
+
                 # 202 (async lookup; try again momentarily)
-                if resp.status_code == 201 or 202:
+                if resp.status_code == 201 or resp.status_code == 202:
                     print("request is pending.")
                     time.sleep(SLEEP_LENGTH)
                     continue
@@ -817,5 +867,10 @@ def clearbit_routines(request=None, streaming=False):
         # library makes it unclear that this is the case
         # ref: https://github.com/clearbit/clearbit-python/blob
         # /master/clearbit/resource.py
-
+    try:
+        if resp.status_code == 200 or resp.status_code == 201 or \
+                resp.status_code == 202:
+            resp = resp.json()
+    except AttributeError as e:
+        pass
     return resp
