@@ -1,9 +1,6 @@
 """
 constants.py : contains constant values used by the various functions.
 """
-from __future__ import print_function, division, unicode_literals, \
-    absolute_import
-
 __author__ = "Jason Wolosonovich <jason@avaland.io>"
 __license__ = "BSD 3 Clause"
 
