@@ -1,29 +1,18 @@
 """
 crawler_service.py: Utility functions used by the crawler service.
 """
-from __future__ import print_function, division, unicode_literals, \
-    absolute_import
-
-try:
-    # for py 3.x
-    from urllib.parse import urlparse
-except ImportError:
-    # for py 2.7
-    from urlparse import urlparse
-
+__author__ = "Jason Wolosonovich <jason@avaland.io>"
+__license__ = "BSD 3 clause"
+from urllib.parse import urlparse
 import re
-import requests
-
 import json
 
-from google.cloud import language
+import requests
+import google.cloud.language as language
 from bs4 import BeautifulSoup
 
 from .classes import MetadataMixin
 
-__author__ = "Jason Wolosonovich <jason@avaland.io>"
-__license__ = "BSD 3 clause"
-
 
 HEADERS = {
     "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) "
@@ -124,26 +113,31 @@ def get_url(ip_address=None):
 def get_content_class(content=None):
     """Utility function that takes website content and returns the
     classification of that text by Google."""
-    print("get_content_class()")
-    language_client = language.LanguageServiceClient()
+    try:
+        print("get_content_class()")
+        language_client = language.LanguageServiceClient()
 
-    document = language.types.Document(
-        content=content,
-        type=language.enums.Document.Type.PLAIN_TEXT)
+        document = language.types.Document(
+            content=content,
+            type=language.enums.Document.Type.PLAIN_TEXT)
 
-    response = language_client.classify_text(document)
+        response = language_client.classify_text(document)
 
-    categories = response.categories
+        categories = response.categories
 
-    result = {}
+        result = {}
 
-    for category in categories:
-        result[category.name] = category.confidence
-
-    # google may not return anything
-    if len(result) == 0:
-        result["No Category Available"] = 0.0
+        for category in categories:
+            result[category.name] = category.confidence
 
+        # google may not return anything
+        if len(result) == 0:
+            result["No Category Available"] = 0.0
+    except Exception as e:
+        print(e)
+        result = {
+            "An Exception Occurred": 0.0
+        }
     return result
 
 
@@ -346,9 +340,15 @@ def make_crawler_gcs_payload(request=None):
     # TODO: should we keep all the content classifications if > 1 are
     # returned?
     if "No Category Available" in r["content_classification"].keys():
-        p["classification_category"] = None
+        p["classification_category"] = "No Category Available"
         p["classification_confidence"] = 0.0
-        p["tier1_classification"] = None
+        p["tier1_classification"] = "No Category Available"
+        p["tier2_classification"] = None
+        p["tier3_classification"] = None
+    elif "An Exception Occurred" in r["content_classification"].keys():
+        p["classification_category"] = "An Exception Occurred"
+        p["classification_confidence"] = 0.0
+        p["tier1_classification"] = "An Exception Occurred"
         p["tier2_classification"] = None
         p["tier3_classification"] = None
     else:
@@ -439,7 +439,7 @@ def make_crawler_bq_payload(request=None):
     return p
 
 
-def wordpress_routines(request=None, is_parsed=True):
+def wordpress_routines(request=None, has_html=True, is_parsed=False):
     """Utility function containing all the wordpress enrichment 
     routines."""
     print("wordpress_routines()")
@@ -447,22 +447,31 @@ def wordpress_routines(request=None, is_parsed=True):
     # container for holding the crawler results
     resp = MetadataMixin()
 
-    # add the domain and url to the metadata container
-    resp["domain"] = request["domain"]
-    resp["url"] = request["url"]
-
-    if is_parsed is False:
+    # TODO: clean up the logic here
+    if has_html is False:
+        resp["url"] = request["url"]
         # crawl the site and return the html for parsing
         resp["document"] = crawl_and_parse(url=resp["url"])
-    elif is_parsed is True:
-        resp["document"] = request["document"]
+    elif has_html is True:
+        # add the domain and url to the metadata container
+        # resp["domain"] = request["domain"]
+        if is_parsed is True:
+            resp["document"] = request["document"]
+        elif is_parsed is False:
+            resp["document"] = BeautifulSoup(request["document"],
+                                             "html.parser")
 
-    # get the word press themes
-    resp["wp_themes"] = get_wp_themes(document=resp["document"])
-
-    # get the word press plugins
-    resp["wp_plugins"] = get_wp_plugins(document=resp["document"])
+    try:
+        # get the word press themes
+        resp["wp_themes"] = get_wp_themes(document=resp["document"])
+    except Exception as e:
+        resp["wp_themes"] = "ERROR"
 
+    try:
+        # get the word press plugins
+        resp["wp_plugins"] = get_wp_plugins(document=resp["document"])
+    except Exception as e:
+        resp["wp_plugins"] = "ERROR"
     return resp
 
 
@@ -535,23 +544,22 @@ def domain_routines(request=None):
 
 
 # TODO: can we abstract this to fit all cases (tags, tech, wp)
-def make_crawler_wordpress_payload(request=None):
+def make_wordpress_asset_history_bq_payload(request=None):
     """Utility function that creates a payload for the Wordpress
     bucket."""
-    print("make_crawler_wordpress_payload()")
+    print("make_wordpress_asset_history_payload()")
     r = request.copy()
     p = MetadataMixin()
 
     p["refinery_company_id"] = r["refinery_company_id"]
     p["refined_at"] = r["refined_at"]
     p["refined_date"] = r["refined_date"]
-    p["domain"] = r["domain"]
-    p["url"] = r["url"]
-    p["ip_revealed"] = r["ip_revealed"]
-    p["fuzzy_match"] = r["fuzzy_match"]
+    p["html_used"] = r["document"]
     # TODO: add additional lists here (wix, squarespace, etc.)
     if len(r["wp_themes"]) != 0:
         p["wp_themes"] = r["wp_themes"]
+    else:
+        p["wp_themes"] = list()
     if len(r["wp_plugins"]) != 0:
         p["wp_plugins"] = r["wp_plugins"]
     print("payload: {}".format(p))
