@@ -2,8 +2,8 @@
 functions.py: Utility functions used throughout the services within the
               Refinery.
 """
-from __future__ import print_function, division, unicode_literals, \
-    absolute_import
+__author__ = "Jason Wolosonovich <jason@avaland.io>"
+__license__ = "BSD 3 clause"
 
 import time
 import re
@@ -11,18 +11,14 @@ import base64
 import json
 
 import requests
-from google.cloud import storage, pubsub
-from google.cloud import bigquery as bq
+import google.cloud.pubsub as ps
+import google.cloud.bigquery as bq
 import validators
-import gcsfs
 
 from .crawler_service import HEADERS
 
-__author__ = "Jason Wolosonovich <jason@avaland.io>"
-__license__ = "BSD 3 clause"
 
-
-def upload_to_gcs(payload=None, project_name=None,bucket_name=None,
+def upload_to_gcs(fs_client=None, payload=None, bucket_name=None,
                   file_name=None, file_suffix=None):
     """Utility function to upload the json to GCS."""
     # TODO: add `content_type` and `content_encoding` when they become
@@ -30,20 +26,7 @@ def upload_to_gcs(payload=None, project_name=None,bucket_name=None,
     print("upload_to_gcs()")
 
     try:
-        fs = gcsfs.GCSFileSystem(
-            project=project_name,
-            access="full_control",
-            token="cloud",
-            # consistency="md5",
-            cache_timeout=None,
-            secure_serialize=True,
-            check_connection=True
-        )
-
-        fs.retries = 7
-        fs.connect(method="cloud")
-
-        with fs.open(bucket_name + "/" + file_name + file_suffix,
+        with fs_client.open(bucket_name + "/" + file_name + file_suffix,
                      "w") as f:
             f.write(json.dumps(payload))
         print("payload: {}".format(payload))
@@ -83,27 +66,14 @@ def upload_to_gcs(payload=None, project_name=None,bucket_name=None,
     return "SEE ERROR LOGS"
 
 
-def download_from_gcs(bucket_name=None, project_name=None,
-                      file_name=None):
+def download_from_gcs(fs_client=None, bucket_name=None,
+                      project_name=None, file_name=None):
     """Utility function to upload the json to GCS."""
     print("download_from_gcs()")
     try:
-        fs = gcsfs.GCSFileSystem(
-            project=project_name,
-            access="full_control",
-            token="cloud",
-            # consistency="md5",
-            cache_timeout=None,
-            secure_serialize=True,
-            check_connection=True
-        )
-
-        fs.retries = 7
-        fs.connect(method="cloud")
-
         # return the payload as a byte string since we don't know what
         # native format it might be in
-        payload = fs.cat(bucket_name + "/" + file_name)
+        payload = fs_client.cat(bucket_name + "/" + file_name)
         return payload
 
     except Exception as e:
@@ -140,7 +110,7 @@ def download_from_gcs(bucket_name=None, project_name=None,
     #     }
     #
     #     print(err)
-    return
+    # return
 
 
 def callback(future):
@@ -150,19 +120,20 @@ def callback(future):
     return "OK, 200"
 
 
-def publish_to_endpoint(messages=None, max_bytes=10000000,
+def publish_to_endpoint(messages=None,
+                        max_bytes=10000000,
                         max_latency=0.05, max_messages=1000,
                         delay_length_in_seconds=None):
     print("publish_to_endpoint()")
     messages_published = 0
     start = time.time()
     # apply the batch settings if specified
-    batch_settings = pubsub.types.BatchSettings(
+    batch_settings = ps.types.BatchSettings(
         max_bytes=max_bytes,
         max_latency=max_latency,
         max_messages=max_messages
     )
-    pubsub_client = pubsub.PublisherClient(
+    pubsub_client = ps.PublisherClient(
         batch_settings=batch_settings
     )
     # TODO: find a universal way to encode the message so we don't
@@ -361,12 +332,44 @@ def get_domain_from_email(email=None):
     return domain
 
 
-def insert_one_to_bq(dataset=None, table=None, schema=None,
-                     payload=None, payload_type=None):
+def insert_one_to_bq(bq_client=None, dataset=None, table=None,
+                     schema=None, payload=None, payload_type=None):
     """Utility function for inserting json rows into the specified
     table."""
     print("insert_one_to_bq()")
 
+    # we may encounter an error when parsing html for wp plugins and
+    # themes
+    if payload_type == "wordpress_error":
+        print("inserting wordpress enrichment errors.")
+        row = [
+            (
+                payload["refinery_company_id"],
+                payload["refined_at"],
+                payload["refined_date"],
+                payload["error_type"],
+                payload["html_used"]
+            )
+        ]
+    # when an email/domain fails to be enriched we'll keep track
+    if payload_type == "app_lookup_error":
+        print("inserting app enrichment errors.")
+        row = [
+            (
+                payload["refined_at"],
+                payload["refined_date"],
+                payload["sfdc_lead_id"],
+                payload["sfdc_contact_id"],
+                payload["sfdc_asset_id"],
+                payload["sfdc_oppty_id"],
+                payload["sfdc_acct_id"],
+                payload["app_name"],
+                payload["domain"],
+                payload["email"]
+            )
+        ]
+
+
     if payload_type == "mobile":
         print("inserting mobile test results.")
         row = [
@@ -591,7 +594,7 @@ def insert_one_to_bq(dataset=None, table=None, schema=None,
     for n in range(max_retries):
         try:
             # configs for bq
-            client = bq.Client()
+
             # job_config = bq.LoadJobConfig()
             # job_config.schema = schema
             # job_config.source_format = \
@@ -599,7 +602,7 @@ def insert_one_to_bq(dataset=None, table=None, schema=None,
             # job_config.write_disposition = \
             #     bq.job.WriteDisposition.WRITE_APPEND
 
-            dataset_ref = client.dataset(dataset)
+            dataset_ref = bq_client.dataset(dataset)
             dataset = bq.Dataset(dataset_ref)
             table_ref = dataset.table(table)
             table = bq.Table(table_ref,
@@ -612,7 +615,7 @@ def insert_one_to_bq(dataset=None, table=None, schema=None,
             print("payload type: {}".format(payload_type))
 
             # attempt to insert the record
-            errors = client.insert_rows(
+            errors = bq_client.insert_rows(
                 table,
                 row,
                 selected_fields=schema,
@@ -634,15 +637,14 @@ def insert_one_to_bq(dataset=None, table=None, schema=None,
     return "success: {}".format(success)
 
 
-
-def insert_many_to_bq(dataset=None, table=None, schema=None,
-                      payload=None, payload_type=None):
+def insert_many_to_bq(bq_client=None, dataset=None, table=None,
+                      schema=None, payload=None, payload_type=None):
     """Utility function for inserting json rows into the specified
     table."""
     print("insert_many_to_bq()")
 
     # configs for bq
-    client = bq.Client()
+    # client = bq.Client()
     # job_config = bq.LoadJobConfig()
     # job_config.schema = schema
     # job_config.source_format = \
@@ -650,7 +652,7 @@ def insert_many_to_bq(dataset=None, table=None, schema=None,
     # job_config.write_disposition = \
     #     bq.job.WriteDisposition.WRITE_APPEND
 
-    dataset_ref = client.dataset(dataset)
+    dataset_ref = bq_client.dataset(dataset)
     dataset = bq.Dataset(dataset_ref)
     table_ref = dataset.table(table)
     table = bq.Table(table_ref,
@@ -662,23 +664,19 @@ def insert_many_to_bq(dataset=None, table=None, schema=None,
     print("payload: {}".format(payload))
     print("payload type: {}".format(payload_type))
 
-    if payload_type == "crawler_tech":
+    if payload_type == "wordpress_assets":
         keys = payload.keys()
         if "wp_themes" in keys:
-            print("inserting themes.")
+            print("inserting wordpress themes.")
             for theme in payload["wp_themes"]:
                 row = [
                     (
                         payload["refinery_company_id"],
                         payload["refined_at"],
                         payload["refined_date"],
-                        payload["domain"],
-                        payload["url"],
-                        payload["ip_revealed"],
-                        payload["fuzzy_match"],
                         theme,
                         "theme",
-                        "wordpress"
+                        payload["document"]
                     )
                 ]
 
@@ -686,7 +684,7 @@ def insert_many_to_bq(dataset=None, table=None, schema=None,
                 for n in range(max_retries):
                     try:
                         # attempt to insert the record
-                        errors = client.insert_rows(
+                        errors = bq_client.insert_rows(
                             table,
                             row,
                             selected_fields=schema,
@@ -707,20 +705,16 @@ def insert_many_to_bq(dataset=None, table=None, schema=None,
                         continue
 
         if "wp_plugins" in keys:
-            print("inserting plugins.")
+            print("inserting wordpress plugins.")
             for plugin in payload["wp_plugins"]:
                 row = [
                     (
                         payload["refinery_company_id"],
                         payload["refined_at"],
                         payload["refined_date"],
-                        payload["domain"],
-                        payload["url"],
-                        payload["ip_revealed"],
-                        payload["fuzzy_match"],
                         plugin,
                         "plugin",
-                        "wordpress"
+                        payload["document"]
                     )
                 ]
 
@@ -728,7 +722,7 @@ def insert_many_to_bq(dataset=None, table=None, schema=None,
                 for n in range(max_retries):
                     try:
                         # attempt to insert the record
-                        errors = client.insert_rows(
+                        errors = bq_client.insert_rows(
                             table,
                             row,
                             selected_fields=schema,
@@ -768,7 +762,7 @@ def insert_many_to_bq(dataset=None, table=None, schema=None,
             for n in range(max_retries):
                 try:
                     # attempt to insert the record
-                    errors = client.insert_rows(
+                    errors = bq_client.insert_rows(
                         table,
                         row,
                         selected_fields=schema,
@@ -807,7 +801,7 @@ def insert_many_to_bq(dataset=None, table=None, schema=None,
             for n in range(max_retries):
                 try:
                     # attempt to insert the record
-                    errors = client.insert_rows(
+                    errors = bq_client.insert_rows(
                         table,
                         row,
                         selected_fields=schema,
@@ -847,7 +841,7 @@ def insert_many_to_bq(dataset=None, table=None, schema=None,
             for n in range(max_retries):
                 try:
                     # attempt to insert the record
-                    errors = client.insert_rows(
+                    errors = bq_client.insert_rows(
                         table,
                         row,
                         selected_fields=schema,
@@ -887,7 +881,7 @@ def insert_many_to_bq(dataset=None, table=None, schema=None,
             for n in range(max_retries):
                 try:
                     # attempt to insert the record
-                    errors = client.insert_rows(
+                    errors = bq_client.insert_rows(
                         table,
                         row,
                         selected_fields=schema,
@@ -897,6 +891,7 @@ def insert_many_to_bq(dataset=None, table=None, schema=None,
                     if len(errors) != 0:
                         print(errors)
                         continue
+                    success = True
                     break
                 except Exception as e:
                     if n == max_retries - 1:
@@ -924,7 +919,7 @@ def insert_many_to_bq(dataset=None, table=None, schema=None,
             for n in range(max_retries):
                 try:
                     # attempt to insert the record
-                    errors = client.insert_rows(
+                    errors = bq_client.insert_rows(
                         table,
                         row,
                         selected_fields=schema,
@@ -963,7 +958,7 @@ def insert_many_to_bq(dataset=None, table=None, schema=None,
             for n in range(max_retries):
                 try:
                     # attempt to insert the record
-                    errors = client.insert_rows(
+                    errors = bq_client.insert_rows(
                         table,
                         row,
                         selected_fields=schema,
